# -*- coding: utf-8 -*-
"""
:Author: HuangJianYi
:Date: 2020-04-16 14:38:22
@LastEditTime: 2021-07-28 11:15:56
@LastEditors: HuangJianYi
:Description: 基础路由
"""
# 框架引用
from seven_framework.web_tornado.monitor import MonitorHandler
from seven_cloudapp_frame.handlers.core import *
from seven_cloudapp_frame.handlers.server import *
from seven_cloudapp_frame.handlers.client import *

def seven_cloudapp_frame_route():
    return [
        (r"/monitor", MonitorHandler),
        (r"/", IndexHandler),
        #客户端
        (r"/client/address", address.AddressInfoListHandler),
        (r"/client/login", user.LoginHandler),
        (r"/client/authorize", user.AuthorizeHandler),
        (r"/client/apply_black_unbind", user.ApplyBlackUnbindHandler),
        (r"/client/user_asset_list", user.UserAssetListHandler),
        (r"/client/asset_log_list", user.AssetLogListHandler),
        (r"/client/theme_info", theme.ThemeInfoHandler),
        (r"/client/save_theme", theme.SaveThemeHandler),
        (r"/client/save_skin", theme.SaveSkinHandler),
        (r"/client/theme_info_list", theme.ThemeInfoListHandler),
        (r"/client/skin_info_list", theme.SkinInfoListHandler),

        #千牛端
        (r"/server/saas_custom", base_s.SaasCustomHandler),
        (r"/server/login", user_s.LoginHandler),
        (r"/server/send_sms", base_s.SendSmsHandler),
        (r"/server/stat_report_list", report_s.StatReportListHandler),
        (r"/server/trend_report_list", report_s.TrendReportListHandler),
        (r"/server/update_user_status", user_s.UpdateUserStatusHandler),
        (r"/server/update_user_status_by_black", user_s.UpdateUserStatusByBlackHandler),
        (r"/server/audit_user_black", user_s.AuditUserBlackHandler),
        (r"/server/user_black_list", user_s.UserBlackListHandler),
        (r"/server/update_user_asset", user_s.UpdateUserAssetHandler),
        (r"/server/asset_log_list", user_s.AssetLogListHandler),
    ]


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-28 09:54:51
@LastEditTime: 2021-07-28 18:00:35
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.db_models.act.act_info_model import *
from seven_cloudapp_frame.models.seven_model import *

class ActBaseModel():
    """
    :description: 活动信息基类
    """
    def __init__(self, context):
        self.context = context

    def _get_act_info_cache_key(self, act_id):
        """
        :description: 获取用户信息缓存key
        :param act_id: 活动标识
        :return: 
        :last_editors: HuangJianYi
        """
        return f"act_info:actid_{act_id}"

    def get_act_info_dict(self,act_id):
        """
        :description: 获取活动信息
        :param act_id: 活动标识
        :return: 返回应用信息
        :last_editors: HuangJianYi
        """
        act_info_dict = ActInfoModel(context=self.context).get_dict_by_id(act_id)
        if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
            return None
        return act_info_dict

    def get_act_info_dict_cache(self,act_id):
        """
        :description: 获取活动信息
        :param act_id: 活动标识
        :return: 返回应用信息
        :last_editors: HuangJianYi
        """
        cache_key = self._get_act_info_cache_key(act_id)
        redis_init = SevenHelper.redis_init()
        act_info_dict = redis_init.get(cache_key)
        if act_info_dict:
            act_info_dict = json.loads(act_info_dict)
        else:
            act_info_dict = self.get_act_info_dict(act_id)
            if act_info_dict:
                redis_init.set(cache_key, SevenHelper.json_dumps(act_info_dict), ex=config.get_value("cache_expire", 60 * 1))
        return act_info_dict
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-07-28 09:54:51
@LastEditTime: 2021-07-28 18:01:49
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.db_models.app.app_info_model import *
from seven_cloudapp_frame.models.seven_model import *

class AppBaseModel():
    """
    :description: 应用信息基类
    """
    def __init__(self, context):
        self.context = context

    def _get_app_info_cache_key(self, app_id):
        """
        :description: 获取应用信息缓存key
        :param app_id: 应用标识
        :return: 
        :last_editors: HuangJianYi
        """
        return f"app_info:appid_{app_id}"

    def get_app_info_dict(self,app_id):
        """
        :description: 获取应用信息
        :param app_id: 应用标识
        :return: 返回应用信息
        :last_editors: HuangJianYi
        """
        return AppInfoModel(context=self).get_dict("app_id=%s", params=[app_id])
    
    def get_app_info_dict_cache(self,app_id):
        """
        :description: 获取应用信息
        :param app_id: 应用标识
        :return: 返回应用信息
        :last_editors: HuangJianYi
        """
        cache_key = self._get_app_info_cache_key(app_id)
        redis_init = SevenHelper.redis_init()
        app_info_dict = redis_init.get(cache_key)
        if app_info_dict:
            app_info_dict = json.loads(app_info_dict)
        else:
            app_info_dict = self.get_app_info_dict(app_id)
            if app_info_dict:
                redis_init.set(cache_key, SevenHelper.json_dumps(app_info_dict), ex=config.get_value("cache_expire", 60 * 1))
        return app_info_dict